@@ -179,6 +179,7 @@ get_icon(const icon_theme *theme,
     GdkPixbuf *image = NULL;
     const gchar *sizedir;
     gchar *filename = NULL, *suffix = "";
+    GError *error = NULL;
 
     g_assert(theme != NULL);
     if (G_UNLIKELY(!theme)) {
@@ -197,11 +198,15 @@ get_icon(const icon_theme *theme,
     /* check whether icon has been verified to be missing before */
     if (!icon_missing(theme, sizedir, symbol_name, suffix)) {
         filename = make_icon_filename(theme, sizedir, symbol_name, suffix);
-        image = quiet_gdk_pixbuf_new_from_file_at_scale(filename, size, size, TRUE, NULL);
+        image = quiet_gdk_pixbuf_new_from_file_at_scale(filename, size, size, TRUE, &error);
     }
 
     if (image == NULL) {
         /* remember failure for future lookups */
+        if (error) {
+            g_warning ("Failed to load pixbuf: %s", error->message);
+            g_error_free (error);
+        }
         if (filename) {
             weather_debug("Unable to open image: %s", filename);
             remember_missing_icon(theme, sizedir, symbol_name, suffix);
@@ -383,11 +388,7 @@ icon_theme_compare(gconstpointer a,
 static GArray *
 find_themes_in_dir(const gchar *path)
 {
-    GArray *themes = NULL;
     GDir *dir;
-    icon_theme *theme;
-    gchar *themedir;
-    const gchar *dirname;
 
     g_assert(path != NULL);
     if (G_UNLIKELY(path == NULL))
@@ -396,6 +397,11 @@ find_themes_in_dir(const gchar *path)
     weather_debug("Looking for icon themes in %s.", path);
     dir = g_dir_open(path, 0, NULL);
     if (dir) {
+        GArray *themes;
+        icon_theme *theme;
+        gchar *themedir;
+        const gchar *dirname;
+
         themes = g_array_new(FALSE, TRUE, sizeof(icon_theme *));
 
         while ((dirname = g_dir_read_name(dir))) {
@@ -412,10 +418,12 @@ find_themes_in_dir(const gchar *path)
         }
         g_dir_close(dir);
         weather_debug("Found %d icon theme(s) in %s.", themes->len, path);
-    } else
+        g_array_sort(themes, (GCompareFunc) icon_theme_compare);
+        return themes;
+    } else {
         weather_debug("Could not list directory %s.", path);
-    g_array_sort(themes, (GCompareFunc) icon_theme_compare);
-    return themes;
+        return NULL;
+    }
 }
 
 
@@ -447,7 +455,7 @@ find_icon_themes(void)
     /* look in user directory first */
     dir = get_user_icons_dir();
     found = find_themes_in_dir(dir);
-    g_free(dir);
+
     if (found) {
         if (found->len > 0)
             themes = g_array_append_vals(themes, found->data, found->len);
@@ -463,6 +471,7 @@ find_icon_themes(void)
     }
 
     weather_debug("Found %d icon themes in total.", themes->len, dir);
+    g_free(dir);
     return themes;
 }
 
