@@ -188,7 +188,7 @@ parse_timestring(const gchar *ts,
 }
 
 
-const gchar *
+static const gchar *
 parse_moonposition (gdouble pos) {
     if (pos < 0.0 || pos > 100.0)
         return "Unknown";
@@ -445,28 +445,28 @@ parse_astro_time(xmlNode *cur_node)
         if (child_node->type == XML_ELEMENT_NODE) {
             if (NODE_IS_TYPE(child_node, "sunrise")) {
                 sunrise = remove_timezone_offset(PROP(child_node, "time"));
-                astro->sunrise = parse_timestring(sunrise, NULL, FALSE);
+                astro->sunrise = parse_timestring(sunrise, NULL, TRUE);
                 xmlFree(sunrise);
                 sun_rises = TRUE;
             }
 
             if (NODE_IS_TYPE(child_node, "moonset")) {
                 moonset = remove_timezone_offset(PROP(child_node, "time"));
-                astro->moonset = parse_timestring(moonset, NULL, FALSE);
+                astro->moonset = parse_timestring(moonset, NULL, TRUE);
                 xmlFree(moonset);
                 moon_sets = TRUE;
             }
 
             if (NODE_IS_TYPE(child_node, "sunset")) {
                 sunset = remove_timezone_offset(PROP(child_node, "time"));
-                astro->sunset = parse_timestring(sunset, NULL, FALSE);
+                astro->sunset = parse_timestring(sunset, NULL, TRUE);
                 xmlFree(sunset);
                 sun_sets = TRUE;
             }
 
             if (NODE_IS_TYPE(child_node, "moonrise")) {
                 moonrise = remove_timezone_offset(PROP(child_node, "time"));
-                astro->moonrise = parse_timestring(moonrise, NULL, FALSE);
+                astro->moonrise = parse_timestring(moonrise, NULL, TRUE);
                 xmlFree(moonrise);
                 moon_rises = TRUE;
             }
@@ -478,6 +478,14 @@ parse_astro_time(xmlNode *cur_node)
                 }
                 astro->moon_phase = g_strdup(parse_moonposition(moonposition));
             }
+
+            if (NODE_IS_TYPE(child_node, "solarnoon")) {
+                astro->solarnoon_elevation = extract_double(PROP(child_node, "elevation"));
+            }
+
+            if (NODE_IS_TYPE(child_node, "solarmidnight")) {
+                astro->solarmidnight_elevation = extract_double(PROP(child_node, "elevation"));
+            }
         }
     }
 
@@ -737,6 +745,8 @@ xml_astro_copy(const xml_astro *src)
     dst->moon_never_rises = src->moon_never_rises;
     dst->moon_never_sets = src->moon_never_sets;
     dst->moon_phase = g_strdup(src->moon_phase);
+    dst->solarnoon_elevation = src->solarnoon_elevation;
+    dst->solarmidnight_elevation = src->solarmidnight_elevation;
     return dst;
 }
 
